==> haskell-yesod-core-1.6.25.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-core
version:              1.6.25.1
visibility:           public
id:                   yesod-core-1.6.25.1-6UDadIoOtDgHso5FOCz4HY
key:                  yesod-core-1.6.25.1-6UDadIoOtDgHso5FOCz4HY
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  661d0b93f887d2954c1f3759b7ecec69
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-core-1.6.25.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-core-1.6.25.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.25.1-6UDadIoOtDgHso5FOCz4HY
depends:
    aeson-2.1.2.1-7MxCVi0kerx5YLDSk2pLUu
    attoparsec-aeson-2.1.0.0-IMzfSeyItsQ7EvyYev1746
    auto-update-0.1.6-AP1utvmzPIUwQV2VanrUB base-4.16.4.0
    blaze-html-0.9.1.2-HaKQvzhQnpBFoHAvD3ha93
    blaze-markup-0.8.3.0-KQTuvxmnzOiwuOy2JEzer bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6iepj2tDmcw8EsjS9ZrC5G
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    clientsession-0.9.2.0-Fn2KQqjREjs9spMlBLQAJp
    conduit-1.3.5-LloaTX3XTonCMTqxjFyITj
    conduit-extra-1.3.6-LEnB9jEsP327dg5JWzsMOP containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5 deepseq-1.4.6.1
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    fast-logger-3.1.2-4LJMRGW8TFaEs9fu0cWKD3
    http-types-0.12.3-7JWRluasvw7H51ApZSD2uB
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    monad-logger-0.3.40-JfAL53TpA4mH98fiDEdf50 mtl-2.2.2
    parsec-3.1.15.0 path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    primitive-0.7.4.0-7EmETL08CQ5nNVujSkVxd
    random-1.2.1.2-HuilZN3oosRCcl1kUNb1cn
    resourcet-1.2.6-Eh9ERdfgEXDnlhBOVqt0T
    shakespeare-2.1.0.1-IJxVrNtPYjf4cnUhcPyNdA
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.1-AlCzDj0upKUDRL0dbo521R
    unliftio-0.2.25.0-9SldoQQ4wUo5OsNuvhhgYz
    unordered-containers-0.2.20-47hukrr2IXRFDwJY5DTAr2
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP
    wai-3.2.4-50ldy2bzzWeGf6jgC1yqEF
    wai-extra-3.1.14-3bcPT5XhequFhN0up1gsDY
    wai-logger-2.4.0-1gFaRstmh3DCNRFIAUaQa
    warp-3.3.30-9zUegVk2IoR9mj5yVZRrlX
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.25.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-core
version:              1.6.25.1
visibility:           public
id:                   yesod-core-1.6.25.1-3hGNPh4j5dbKJa9Fcms0Pb
key:                  yesod-core-1.6.25.1-3hGNPh4j5dbKJa9Fcms0Pb
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  9f20a67d8e8c4e2da447c05df8f2f318
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-core-1.6.25.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-core-1.6.25.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.25.1-3hGNPh4j5dbKJa9Fcms0Pb
depends:
    aeson-2.1.2.1-7MxCVi0kerx5YLDSk2pLUu
    attoparsec-aeson-2.1.0.0-IMzfSeyItsQ7EvyYev1746
    auto-update-0.1.6-AP1utvmzPIUwQV2VanrUB base-4.16.4.0
    blaze-html-0.9.1.2-HaKQvzhQnpBFoHAvD3ha93
    blaze-markup-0.8.3.0-KQTuvxmnzOiwuOy2JEzer bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6iepj2tDmcw8EsjS9ZrC5G
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    clientsession-0.9.2.0-Fn2KQqjREjs9spMlBLQAJp
    conduit-1.3.5-LloaTX3XTonCMTqxjFyITj
    conduit-extra-1.3.6-LEnB9jEsP327dg5JWzsMOP containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5 deepseq-1.4.6.1
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    fast-logger-3.1.2-4LJMRGW8TFaEs9fu0cWKD3
    http-types-0.12.3-7JWRluasvw7H51ApZSD2uB
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    monad-logger-0.3.40-JfAL53TpA4mH98fiDEdf50 mtl-2.2.2
    parsec-3.1.15.0 path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    primitive-0.7.4.0-7EmETL08CQ5nNVujSkVxd
    random-1.2.1.2-HuilZN3oosRCcl1kUNb1cn
    resourcet-1.2.6-Eh9ERdfgEXDnlhBOVqt0T
    shakespeare-2.1.0.1-IJxVrNtPYjf4cnUhcPyNdA
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.1-AlCzDj0upKUDRL0dbo521R
    unliftio-0.2.25.0-9SldoQQ4wUo5OsNuvhhgYz
    unordered-containers-0.2.20-47hukrr2IXRFDwJY5DTAr2
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP
    wai-3.2.4-50ldy2bzzWeGf6jgC1yqEF
    wai-extra-3.1.14-3BtV1E8pjQV9dpzvCi2Dmx
    wai-logger-2.4.0-1gFaRstmh3DCNRFIAUaQa
    warp-3.3.30-IDGOMgnZ7DPC9zqUDOOtGr
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
